The HentaiVerse

23421
1021
1269
194
Battle Time
Choose from the Battle Actions highlighted above, and use them to defeat your enemies listed to the right. When all enemies are reduced to zero Health, you win. If your Health reaches zero, you are defeated.

The effect Stunned on Ryouko Asakura has expired.
Replenishment restores 11 points of magic.
Regen restores 56 points of health.
Regeneration restores 382 points of health.
Refreshment restores 2 points of spirit.
Your spike shield hits Ultimate Wind Mage for 5 points of fire damage.
You block the attack from Ultimate Wind Mage.
You gain the effect Overwhelming Strikes.
Void Strike hits Ryouko Asakura for 8443 void damage.
Elec Strike hits Ryouko Asakura for 6145 elec damage.
You hit Ryouko Asakura for 17057 void damage.

Flee
Scan
Shield Bash | Vital Strike | Merciful Blow

Fiery Blast | Inferno
Freeze | Blizzard
Shockblast | Chained Lightning
Gale | Downburst
Smite | Banishment
Corruption | Disintegrate
Drain | Weaken | Imperil
Slow | Sleep | Confuse
Blind | Silence | MagNet
Cure | Regen | Full-Cure
Protection | Haste | Shadow Veil
Absorb | Spark of Life | Spirit Shield
Heartseeker | Arcane Focus

P
Spirit Gem
1
Health Draught
2
Health Potion
3
Health Elixir
4
Mana Draught
5
Mana Potion
6
Mana Elixir
7
Spirit Draught
8
Spirit Potion
9
Spirit Elixir
10
11
12
13
14
15
S1
S2
S3
S4
S5
S6
N1
N2
N3
N4
N5
N6
370
Yuki Nagato
370
Ryouko Asakura
370
Courage And Persistence
370
Gouki
370
Ultimate Wind Mage
370
Darkmaidvvv